#!/usr/bin/env python3
"""
Bielik CLI __main__.py - Entry point for running bielik as a module.

This allows running bielik with: python -m bielik
"""

from .cli.main import main

if __name__ == "__main__":
    main()
